@@ -48,8 +48,7 @@
 #' set.seed(2)
 #' dat <- gamSim(1, n=300, dist="normal", scale=2)
 #' 
-#' fit <- mqgam(y~s(x0)+s(x1)+s(x2)+s(x3), data=dat, err = 0.05, qu = c(0.2, 0.8), 
-#'              control = list("tol" = 0.05)) # <- semi-sloppy tolerance to speed-up calibration
+#' fit <- mqgam(y~s(x0)+s(x1)+s(x2)+s(x3), data=dat, err = 0.05, qu = c(0.2, 0.8))
 #' 
 #' invisible( qdo(fit, 0.2, plot, pages = 1) )
 #' 
@@ -62,8 +61,7 @@
 #' # Fit for quantile 0.8 using the best sigma
 #' quSeq <- c(0.2, 0.4, 0.6, 0.8)
 #' set.seed(6436)
-#' fit <- mqgam(accel~s(times, k=20, bs="ad"), data = mcycle, err = 0.05, qu = quSeq, 
-#'        control = list("tol" = 0.01)) # <- semi-sloppy tolerance to speed-up calibration
+#' fit <- mqgam(accel~s(times, k=20, bs="ad"), data = mcycle, err = 0.05, qu = quSeq)
 #' 
 #' # Plot the fit
 #' xSeq <- data.frame(cbind("accel" = rep(0, 1e3), "times" = seq(2, 58, length.out = 1e3)))
@@ -80,6 +78,10 @@ mqgam <- function(form, data, qu, lsig = NULL, err = 0.05,
 {
   nq <- length(qu)
   
+  # Removing all NAs and unused levels from data
+  if( inherits(data, "groupedData") ) { data <- as.data.frame( data ) }
+  data <- droplevels( na.omit( data ) )
+  
   if( length(err) != nq ){
     if(length(err) == 1) { 
       err <- rep(err, nq) 
@@ -131,6 +133,7 @@ mqgam <- function(form, data, qu, lsig = NULL, err = 0.05,
     if(ii > 1){
       .out$model  <- NULL
       .out$smooth <- NULL 
+      .out$call$data <- NULL
     } 
     
     return( .out )
@@ -140,11 +143,15 @@ mqgam <- function(form, data, qu, lsig = NULL, err = 0.05,
   names(out[["fit"]]) <- qu
   out[["model"]] <- out[["fit"]][[1]][["model"]]
   out[["smooth"]] <- out[["fit"]][[1]][["smooth"]]
+  out[["data"]] <- out[["fit"]][[1]][["call"]][["data"]]
   out[["fit"]][[1]][["model"]] <- NULL
   out[["fit"]][[1]][["smooth"]] <- NULL
+  out[["fit"]][[1]][["call"]][["data"]] <- NULL
+  
+  class(out) <- "mqgam"
   
 #   out[["qu"]] <- qu
-#   out[["lambda"]] <- lam
+#   out[["co"]] <- co
 #   out[["lsig"]] <- lsig
   
   return( out )
